﻿using Microsoft.AspNetCore.Mvc;
using StackExchange.Redis;
using System.Threading.Tasks;

    namespace RedisInWebApi.Controllers
{
    [Route("[controller]")]
    [ApiController]
    public class ValuesController : ControllerBase
    {
        private readonly IConnectionMultiplexer _connectionMultiplexer;
        private readonly IDatabase _redis;

        public ValuesController(IConnectionMultiplexer connectionMultiplexer)
        {
            _connectionMultiplexer = connectionMultiplexer;
            _redis = _connectionMultiplexer.GetDatabase();
        }

        [HttpGet("{key}")]
        public async Task<IActionResult> Get(string key)
        {
            return Ok((await _redis.StringGetAsync(key)).ToString());
        }

        [HttpPost]
        public async Task<IActionResult> Post([FromBody] KeyValue keyValue)
        {
            await _redis.StringSetAsync(keyValue.Key, keyValue.Value);
            return Created("", keyValue.Value);
        }

        [HttpPut("{key}")]
        public async Task<IActionResult> Put(string key, [FromBody] string value)
        {
            await _redis.StringSetAsync(key, value);
            return NoContent();
        }

        [HttpDelete("{key}")]
        public async Task<IActionResult> Delete(string key)
        {
            await _redis.KeyDeleteAsync(key);
            return NoContent();
        }
    }

    public class KeyValue
    {
        public string Key { get; set; }
        public string Value { get; set; }
    }
}
